@@ -186,8 +186,8 @@ class n900Fly (hildon.Window):
 		dialog = gtk.AboutDialog()
 		dialog.set_name("n900Fly")
 		dialog.set_logo_icon_name("n900Fly")
-		dialog.set_comments('Free-Fall Stopwatch and Distance Estimator. Irresponsibly throw your phone into the air and check how high it goes!')
-		dialog.set_version("0.1.4")
+		dialog.set_comments('Uses the accelerometer to measure how high you can throw your n900 in the air.')
+		dialog.set_version("0.1.5")
 		dialog.set_copyright("By Clovis Peruchi Scotti (aka cpscotti)")
 		dialog.set_website("www.das.ufsc.br/~scotti")
 		dialog.connect ("response", lambda d, r: d.destroy())
